/**
 * The console object provides access to the browser's debugging console. The specifics of how it works vary from browser to browser, but there is a de facto set of features that are typically provided.
 */
var Console = {
}
/**
 * Outputs a warning message to the Web Console.
 * @syntax console.warn(obj1 [, obj2, ..., objN);<br>console.warn(msg [, subst1, ..., substN);
 * @param {Object} obj1...objN A list of JavaScript objects to output. The string representations of each of these objects are appended together in the order listed and output.
 * @param {String} msg A JavaScript string containing zero or more substitution strings.
 * @param {String} subst1...substN JavaScript objects with which to replace substitution strings within msg. This gives you additional control over the format of the output.
 * @returns {undefined} 
 * @static
 */
Console.warn = function(obj1 ) {};

/**
 * Starts a timer you can use to track how long an operation takes. You give each timer a unique name, and may have up to 10,000 timers running on a given page. When you call console.timeEnd() with the same name, the browser will output the time, in milliseconds, that elapsed since the timer was started.
 * @syntax console.time(timerName);
 * @param {String} timerName The name to give the new timer. This will identify the timer; use the same name when calling console.timeEnd() to stop the timer and get the time output to the console.
 * @returns {undefined} 
 * @static
 */
Console.time = function(timerName) {};

/**
 * Stops a timer that was previously started by calling console.time() .
 * @syntax console.timeEnd(timerName);
 * @param {String} timerName The name of the timer to stop. Once stopped, the elapsed time is automatically displayed in the Web Console.
 * @returns {undefined} 
 * @static
 */
Console.timeEnd = function(timerName) {};

/**
 * Outputs an error message to the Web Console.
 * @syntax console.error(obj1 [, obj2, ..., objN);<br>console.error(msg [, subst1, ..., substN);
 * @param {Object} obj1...objN A list of JavaScript objects to output. The string representations of each of these objects are appended together in the order listed and output.
 * @param {String} msg A JavaScript string containing zero or more substitution strings.
 * @param {String} subst1...substN JavaScript objects with which to replace substitution strings within msg. This gives you additional control over the format of the output.
 * @returns {undefined} 
 * @static
 */
Console.error = function(obj1 ) {};

/**
 * Displays an interactive list of the properties of the specified JavaScript object. The output is presented as a hierarchical listing with disclosure triangles that let you see the contents of child objects.
 * @syntax console.dir(object);
 * @param {Object} object A JavaScript object whose properties should be output.
 * @returns {undefined} 
 * @static
 */
Console.dir = function(object) {};

/**
 * Outputs a stack trace to the Web Console.
 * @syntax console.trace()
 * @returns {undefined} 
 * @static
 */
Console.trace = function() {};

/**
 * Creates a new inline group in the Web Console. Unlike console.group() , however, the new group is created collapsed. The user will need to use the disclosure button next to it to expand it, revealing the entries created in the group. Call console.groupEnd() to back out to the parent group.
 * @syntax console.groupCollapsed()
 * @returns {undefined} 
 * @static
 */
Console.groupCollapsed = function() {};

/**
 * Creates a new inline group in the Web Console log. This indents all following output by an additional level, until console.groupEnd() is called.
 * @syntax console.group()
 * @returns {undefined} 
 * @static
 */
Console.group = function() {};

/**
 * Outputs a message to the Web Console.
 * @syntax console.log(obj1 [, obj2, ..., objN);<br>console.log(msg [, subst1, ..., substN);
 * @param {Object} obj1...objN A list of JavaScript objects to output. The string representations of each of these objects are appended together in the order listed and output.
 * @param {String} msg A JavaScript string containing zero or more substitution strings.
 * @param {String} subst1...substN JavaScript objects with which to replace substitution strings within msg. This gives you additional control over the format of the output.
 * @returns {undefined} 
 * @static
 */
Console.log = function(obj1 ) {};

/**
 * Outputs an informational message to the Web Console. In Firefox, a small "i" icon is displayed next to these items in the Web Console's log.
 * @syntax console.info(obj1 [, obj2, ..., objN);<br>console.info(msg [, subst1, ..., substN);
 * @param {Object} obj1...objN A list of JavaScript objects to output. The string representations of each of these objects are appended together in the order listed and output.
 * @param {String} msg A JavaScript string containing zero or more substitution strings.
 * @param {String} subst1...substN JavaScript objects with which to replace substitution strings within msg. This gives you additional control over the format of the output.
 * @returns {undefined} 
 * @static
 */
Console.info = function(obj1 ) {};

/**
 * Exits the current inline group in the Web Console. See Using groups in the console in the console documentation for details and examples.
 * @syntax console.groupEnd()
 * @returns {undefined} 
 * @static
 */
Console.groupEnd = function() {};

/**
 * Represents the Console prototype object.
 * @syntax Console.prototype
 * @static
 */
Console.prototype;

