/**
 * The joint session history of a History object is the union of all the session histories of all browsing contexts of all the fully active Document objects that share the History object's top-level browsing context, with all the entries that are current entries in their respective session histories removed except for the current entry of the joint session history.
 */
var History = {
}
/**
 * Goes to the next page in session history, the same action as when the user clicks the browser's Forward button; this is equivalent to history.go(1).
 * @returns {undefined} 
 */
History.prototype.forward = function() {};

/**
 * Pushes the given data onto the session history stack with the specified title and, if provided, URL. The data is treated as opaque by the DOM; you may specify any JavaScript object that can be serialized.  Note that Firefox currently ignores the title parameter; for more information, see manipulating the browser history.
 * @param {Object} data The state object is a JavaScript object which is associated with the new history entry created by pushState(). Whenever the user navigates to the new state, a popstate event is fired, and the state property of the event contains a copy of the history entry's state object.
 * @param {String} title Passing the empty string here should be safe against future changes to the method. Alternatively, you could pass a short title for the state to which you're moving.
 * @param {String} url The new history entry's URL is given by this parameter. Note that the browser won't attempt to load this URL after a call to pushState(), but it might attempt to load the URL later, for instance after the user restarts her browser. The new URL does not need to be absolute; if it's relative, it's resolved relative to the current URL. The new URL must be of the same origin as the current URL; otherwise, pushState() will throw an exception. This parameter is optional; if it isn't specified, it's set to the document's current URL.
 * @returns {undefined} 
 */
History.prototype.pushState = function() {};

/**
 * Returns the state at the top of the history stack. This is a way to look at the state without having to wait for a popstate event. Read only.
 * @returns {Object} 
 */
History.prototype.state = new Object();

/**
 * Read-only. Returns the number of elements in the session history, including the currently loaded page. For example, for a page loaded in a new tab this property returns 1.
 * @returns {Number} 
 */
History.prototype.length = new Number();

/**
 * Goes to the previous page in session history, the same action as when the user clicks the browser's Back button. Equivalent to history.go(-1).
 * @returns {undefined} 
 */
History.prototype.back = function() {};

/**
 * Updates the most recent entry on the history stack to have the specified data, title, and, if provided, URL. The data is treated as opaque by the DOM; you may specify any JavaScript object that can be serialized.  Note that Firefox currently ignores the title parameter; for more information, see manipulating the browser history.
 * @param {Object} data The state object is a JavaScript object which is associated with the new history entry created by pushState(). Whenever the user navigates to the new state, a popstate event is fired, and the state property of the event contains a copy of the history entry's state object.
 * @param {String} title Passing the empty string here should be safe against future changes to the method. Alternatively, you could pass a short title for the state to which you're moving.
 * @param {String} url The new history entry's URL is given by this parameter. Note that the browser won't attempt to load this URL after a call to pushState(), but it might attempt to load the URL later, for instance after the user restarts her browser. The new URL does not need to be absolute; if it's relative, it's resolved relative to the current URL. The new URL must be of the same origin as the current URL; otherwise, pushState() will throw an exception. This parameter is optional; if it isn't specified, it's set to the document's current URL.
 * @returns {undefined} 
 */
History.prototype.replaceState = function() {};

/**
 * Loads a page from the session history, identified by its relative location to the current page, for example -1 for the previous page or 1 for the next page. When integerDelta is out of bounds (e.g. -1 when there are no previously visited pages in the session history), the method doesn't do anything and doesn't raise an exception. Calling go() without parameters or with a non-integer argument has no effect (unlike Internet Explorer, which supports string URLs as the argument).
 * @param {Number} integerDelta 
 * @returns {undefined} 
 */
History.prototype.go = function() {};

/**
 * Represents the History prototype object.
 * @syntax History.prototype
 * @static
 */
History.prototype;

